securitypolicy

package
v0.1.14 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 26, 2026 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

const StrictProductionEnvVar = "EPACK_STRICT_PRODUCTION"

StrictProductionEnvVar enables strict production mode when set to true/1.

Variables

This section is empty.

Functions

func EnforceStrictProduction

func EnforceStrictProduction(component string, hasUnsafeOverrides bool) error

EnforceStrictProduction blocks insecure execution overrides in strict production mode.

func StrictProductionEnabled

func StrictProductionEnabled() bool

StrictProductionEnabled returns true when strict production mode is enabled.

func ValidateRemoteExecution

func ValidateRemoteExecution(frozen, insecureAllowUnpinned bool) error

ValidateRemoteExecution is a compatibility wrapper around ExecutionPolicy.

Types

type ExecutionPolicy

type ExecutionPolicy struct {
	Frozen        bool
	AllowUnpinned bool
}

ExecutionPolicy captures execution-time security mode for components that may allow unpinned execution.

func (ExecutionPolicy) Enforce

func (p ExecutionPolicy) Enforce() error

Enforce validates policy invariants.

Jump to