Documentation
¶
Overview ¶
Package intoto defines in-toto statement types for evidence pack attestations.
Index ¶
Constants ¶
const ( // StatementType is the in-toto statement type for v1 statements. StatementType = "https://in-toto.io/Statement/v1" // EvidencePackPredicateType is the predicate type for evidence pack attestations. EvidencePackPredicateType = "https://evidencepack.org/attestation/v1" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type EvidencePackPayload ¶
type EvidencePackPayload struct {
PackDigest string `json:"pack_digest"`
Stream string `json:"stream,omitempty"`
}
EvidencePackPayload is the predicate content for evidence pack attestations.
type Statement ¶
type Statement struct {
Type string `json:"_type"`
Subject []Subject `json:"subject"`
PredicateType string `json:"predicateType"`
Predicate EvidencePackPayload `json:"predicate"`
}
Statement represents an in-toto v1 statement. This is the payload that gets signed in the Sigstore bundle.
Click to show internal directories.
Click to hide internal directories.